@@ -1,6 +1,7 @@
-#!/usr/bin/perl
+#!/usr/bin/perl 
 # 
 #  Copyright 2003 (c) Benjamin Drieu
+#  Copyright 2005 (c) Francois Terrot
 #  
 #  This program is free software; you can redistribute it and/or
 #  modify it under the terms of the GNU General Public License as
@@ -21,8 +22,16 @@
 #  personnal details to developers such as addresses, names, amounts,
 #  balances.
 
+my $file_in  = $ARGV[0];
+my $file_out = $ARGV[1];
+my $FD_OUT   = STDOUT;   # Default output is stdout ...
 
-open XML, $ARGV[0] or die $!;
+die "Usage: obfuscate.pl gsb_file_to_obfuscte [obfuscated_gsb_file]\n" if ($#ARGV <0);
+die "It's not a good idea to overwrite the input file !\n" if ("$file_in" eq "$file_out");
+
+open $FD_OUT, ">$file_out" or die $! if ($file_out);
+
+open XML, $file_in or die $!;
 
 my @obfuscate = (
   'Grisbi/Generalites/Backup',
@@ -99,7 +108,7 @@ while (my $line = <XML>)
 
 	$line =~ s/>([^<]*)<\//>$last $total{$last}<\//gi;
     }
-    print $line;
+    print $FD_OUT $line;
 
     if ($line =~ /<\/[^>]+>/ || $line =~ /\/>/)
     {
@@ -108,3 +117,29 @@ while (my $line = <XML>)
 }
 
 close XML;
+
+__END__
+
+=head1 MAIN
+
+obfuscate.pl - Remove all personal information of a GRISBI account to file.
+
+=head1 SYNOPSIS
+
+obfuscate.pl <gsb_file_to_obfuscte> [<obfuscated_gsb_file>]
+
+     Options:
+       gsb_file_to_obfuscte The GRISBI account file you want to remove the personal information from.
+       obfuscated_gsb_file  The result file (optional). If this option is not present, the script
+                            print of the standard output.
+
+=head1 DESCRIPTION
+
+    B<This program> will read the given input file and remove all personal information. 
+    This script can be use when your account make GRISBI crash and the development team request to have a
+    copy of the account file to fix the problem.
+
+    Note: Sometime, GRISBI does no more crash with obfuscated file version. 
+
+=cut
+
