@@ -5,7 +5,7 @@
 /*                                                                            */
 /*     Copyright (C)	2000-2003 Cédric Auger (cedric@grisbi.org)	      */
 /*			2003-2004 Benjamin Drieu (bdrieu@april.org)	      */
-/*			2004 Alain Portal (dionysos@grisbi.org)		      */
+/*			2004 Alain Portal (aportal@univ-montp2.fr)	      */
 /*			http://www.grisbi.org				      */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
@@ -105,7 +105,7 @@ gboolean update_bank_menu ()
 struct struct_banque * ajout_banque ( GtkWidget *bouton, GtkWidget *clist )
 {
     struct struct_banque *banque;
-    gchar *ligne[1];
+    gchar *ligne[2];
     gint ligne_insert;
 
     if ( clist && GTK_IS_CLIST(clist) )
@@ -127,6 +127,8 @@ struct struct_banque * ajout_banque ( GtkWidget *bouton, GtkWidget *clist )
     banque -> nom_correspondant = "";
     liste_struct_banques = g_slist_append ( liste_struct_banques, banque );
     ligne[0] = banque -> nom_banque;
+    ligne[1] = "";
+
 
     if ( clist && GTK_IS_CLIST(clist) )
     {
