@@ -1658,6 +1658,11 @@ void fin_edition_ventilation_echeances ( void )
                                    ":",
                                    2 );
 
+       tableau_char[0] = g_strstrip ( tableau_char[0] );
+
+       if ( tableau_char[1] )
+	   tableau_char[1] = g_strstrip ( tableau_char[1] );
+
 	if ( strlen ( tableau_char[0] ) )
 	{
 	    /* on vérifie ici si c'est un virement */
@@ -2734,9 +2739,7 @@ void validation_ope_de_ventilation_echeances ( struct operation_echeance *operat
 		    /* théoriquement, cette ligne n'est pas nécessaire vu que c'est une modif d'opé de ventil */
 
 		    ope_modifiee -> no_operation_ventilee_associee = operation -> no_operation;
-		    ope_modifiee -> operation_ventilee = 1;
-		
-
+		    ope_modifiee -> operation_ventilee = 0;
 		}
 	    }
 	    else
@@ -2783,7 +2786,7 @@ void validation_ope_de_ventilation_echeances ( struct operation_echeance *operat
 		nouvelle_ope -> type_ope = operation -> type_ope;
 		nouvelle_ope -> auto_man = operation -> auto_man;
 		nouvelle_ope -> no_operation_ventilee_associee = operation -> no_operation;
-		nouvelle_ope -> operation_ventilee = 1;
+		nouvelle_ope -> operation_ventilee = 0;
 
 		/* on ajoute cette opé à la liste */
 
