@@ -1,9 +1,9 @@
 /* ************************************************************************** */
-/* Contient toutes les procdures relatives aux erreurs et  la fin du prog   */
+/* Contient toutes les procédures relatives aux erreurs et à la fin du prog   */
 /*                                                                            */
 /*                                  erreur.c                                  */
 /*                                                                            */
-/*     Copyright (C)	2000-2003 Cdric Auger (cedric@grisbi.org)	      */
+/*     Copyright (C)	2000-2003 Cédric Auger (cedric@grisbi.org)	      */
 /*			2003-2004 Benjamin Drieu (bdrieu@april.org)	      */
 /* 			http://www.grisbi.org				      */
 /*                                                                            */
@@ -46,7 +46,7 @@ extern gint patience_en_cours;
 
 
 /*****************************************************************************************************************/
-/* fonction appele lors de la demande de fermeture du fichier de compte en cours */
+/* fonction appelée lors de la demande de fermeture du fichier de compte en cours */
 /*****************************************************************************************************************/
 
 
@@ -64,7 +64,7 @@ gboolean fermeture_grisbi ( void )
 
     sauve_configuration ();
 
-    /*   si le fichier est modifi, propose l'enregistrement */
+    /*   si le fichier est modifié, propose l'enregistrement */
 
     if ( enregistrement_fichier(-1) )
 	gtk_main_quit();
@@ -72,7 +72,7 @@ gboolean fermeture_grisbi ( void )
       return TRUE;
 
 
-    /* si le fichier n'tait pas dj ouvert, met  0 l'ouverture */
+    /* si le fichier n'était pas déjà ouvert, met à 0 l'ouverture */
 
     if ( !etat.fichier_deja_ouvert
 	 &&
@@ -162,10 +162,10 @@ void traitement_sigsegv ( gint signal_nb )
 
     errmsg = _("Grisbi triggered a segmentation fault and cannot continue its execution.\n\n");
 
-    /*   il y a 3 possibilits : */
-    /*     soit on tait en train de charger un fichier, c'est que celui-ci est corrompu */
-    /* soit on tait en train de sauver un fichier, et l on peut rien faire */
-    /* sinon on essaie de sauver le fichier sous le nom entour de # */
+    /*   il y a 3 possibilités : */
+    /*     soit on était en train de charger un fichier, c'est que celui-ci est corrompu */
+    /* soit on était en train de sauver un fichier, et là on peut rien faire */
+    /* sinon on essaie de sauver le fichier sous le nom entouré de # */
 
     if ( etat.en_train_de_charger || 
 	 etat.en_train_de_sauvegarder || 
@@ -189,14 +189,14 @@ void traitement_sigsegv ( gint signal_nb )
     else 
     {
 	/* c'est un bug pendant le fonctionnement de Grisbi s'il n'y a
-	   pas de nom de fichier, on le cre, sinon on rajoute #
+	   pas de nom de fichier, on le crée, sinon on rajoute #
 	   autour */
 
         gsb_file_default_dir = (gchar *) my_get_gsb_file_default_dir();
 
 	if ( nom_fichier_comptes )
 	{
-	    /* on rcupre le nome du fichier sans le chemin */
+	    /* on récupère le nome du fichier sans le chemin */
 
 	    gchar **parametres;
 	    gint i=0;
