@@ -1,24 +1,28 @@
-/*  Fichier qui s'occupe d'afficher les états */
-
+/* ************************************************************************** */
+/* Fichier qui s'occupe d'afficher les états                                  */
+/*                                                                            */
+/*                            etats_affiche.c                                 */
+/*                                                                            */
 /*     Copyright (C)	2000-2003 Cédric Auger (cedric@grisbi.org)	      */
 /*			2004 Benjamin Drieu (bdrieu@april.org)		      */
-/* 			http://www.grisbi.org				      */
-
-/*     This program is free software; you can redistribute it and/or modify */
-/*     it under the terms of the GNU General Public License as published by */
-/*     the Free Software Foundation; either version 2 of the License, or */
-/*     (at your option) any later version. */
-
-/*     This program is distributed in the hope that it will be useful, */
-/*     but WITHOUT ANY WARRANTY; without even the implied warranty of */
-/*     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the */
-/*     GNU General Public License for more details. */
-
-/*     You should have received a copy of the GNU General Public License */
-/*     along with this program; if not, write to the Free Software */
-/*     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
-
-
+/*			2005 Alain Portal (aportal@univ-montp2.fr)	      */
+/*			http://www.grisbi.org				      */
+/*                                                                            */
+/*  This program is free software; you can redistribute it and/or modify      */
+/*  it under the terms of the GNU General Public License as published by      */
+/*  the Free Software Foundation; either version 2 of the License, or         */
+/*  (at your option) any later version.                                       */
+/*                                                                            */
+/*  This program is distributed in the hope that it will be useful,           */
+/*  but WITHOUT ANY WARRANTY; without even the implied warranty of            */
+/*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             */
+/*  GNU General Public License for more details.                              */
+/*                                                                            */
+/*  You should have received a copy of the GNU General Public License         */
+/*  along with this program; if not, write to the Free Software               */
+/*  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+/*                                                                            */
+/* ************************************************************************** */
 
 #include "include.h"
 #include "structures.h"
@@ -1074,7 +1078,7 @@ gint etat_affiche_affichage_ligne_ope ( struct structure_operation *operation,
 
 	if ( etat_courant -> afficher_no_ope )
 	{
-	    text = itoa ( operation -> no_operation );
+	    text = utils_itoa ( operation -> no_operation );
 
 	    if ( etat_courant -> ope_clickables )
 	    {
@@ -1304,6 +1308,37 @@ gint etat_affiche_affichage_ligne_ope ( struct structure_operation *operation,
 
 	if ( etat_courant -> afficher_cheque_ope )
 	{
+	    /* Si l'opération est une opération de ventilation, il faut rechercher
+	       l'opération mère pour pouvoir récupérer le n° du chèque */
+	    if ( operation -> no_operation_ventilee_associee )
+	    {
+		gpointer **save_ptab;
+		GSList *pTransactionList;
+		gboolean found = FALSE;
+
+		/* On récupère donc la liste des opérations du compte et on en fait
+		   le tour jusqu'à ce qu'on trouve l'opération mère */
+		save_ptab = p_tab_nom_de_compte_variable;
+		p_tab_nom_de_compte_variable = p_tab_nom_de_compte + operation -> no_compte;
+		pTransactionList = LISTE_OPERATIONS;
+		while ( pTransactionList && !found )
+		{
+		    struct structure_operation *pTransaction;
+
+		    pTransaction = pTransactionList -> data;
+		    
+		    if ( pTransaction -> operation_ventilee &&
+			 pTransaction -> no_operation == operation -> no_operation_ventilee_associee &&
+			 pTransaction -> contenu_type )
+		    {
+			operation -> contenu_type = pTransaction -> contenu_type;
+			found = TRUE;
+		    }
+		    pTransactionList = pTransactionList -> next;
+		}
+		p_tab_nom_de_compte_variable = save_ptab;
+	    }
+	    
 	    if ( operation -> contenu_type )
 	    {
 		text = operation -> contenu_type;
@@ -1365,6 +1400,47 @@ gint etat_affiche_affichage_ligne_ope ( struct structure_operation *operation,
 	    colonne = colonne + 2;
 	}
 
+	if ( etat_courant -> afficher_verif_ope )
+	{
+	    
+	    switch ( operation -> pointe )
+	    {
+		case CHECKED_TRANSACTION :
+		
+		    text = g_strdup ( _("C") );
+		    break;
+
+		case RECONCILED_TRANSACTION :
+		
+		    text = g_strdup ( _("R") );
+		    break;
+
+		case TELECHECKED_TRANSACTION :
+		
+		    text = g_strdup ( _("C") );
+		    break;
+
+		case UNCHECKED_TRANSACTION :
+		default :
+		
+		    text = "";
+		    break;
+
+	    }
+
+	    if ( etat_courant -> ope_clickables )
+	    {
+		etat_affiche_attach_label ( text, TEXT_NORMAL, colonne, colonne + 1, ligne, ligne + 1, LEFT, operation );
+	    }
+	    else
+	    {
+		etat_affiche_attach_label ( text, TEXT_NORMAL, colonne, colonne + 1, ligne, ligne + 1, LEFT, NULL );
+	    }
+
+	    etat_affiche_attach_vsep ( colonne + 1, colonne + 2, ligne, ligne + 1 );
+	    colonne = colonne + 2;
+	}
+
 	if ( etat_courant -> afficher_rappr_ope )
 	{
 	    GSList *pointeur;
@@ -1600,7 +1676,7 @@ gint etat_affiche_affiche_categ_etat ( struct structure_operation *operation,
 		if ( operation -> relation_no_operation )
 		{
 		    pointeur_char = g_strconcat ( decalage_categ,
-						  _("Transfers"),
+						  _("Transfert"),
 						  NULL );
 		    ancienne_categ_speciale_etat = 1;
 		}
@@ -2212,6 +2288,13 @@ gint etat_affiche_affiche_titres_colonnes ( gint ligne )
 	colonne = colonne + 2;
     }
 
+    if ( etat_courant -> afficher_verif_ope )
+    {
+	etat_affiche_attach_label ( _("Check"), TEXT_BOLD, colonne, colonne + 1, ligne, ligne + 1, CENTER, NULL );
+	etat_affiche_attach_vsep ( colonne + 1, colonne + 2, ligne, ligne + 1 );
+	colonne = colonne + 2;
+    }
+
     if ( etat_courant -> afficher_rappr_ope )
     {
 	etat_affiche_attach_label ( _("Statement"), TEXT_BOLD, colonne, colonne + 1, ligne, ligne + 1, CENTER, NULL );
