@@ -2,7 +2,7 @@
 /*      etats.c */
 
 /*     Copyright (C)	2000-2003 Cédric Auger (cedric@grisbi.org)	      */
-/*			2004 Benjamin Drieu (bdrieu@april.org)		      */
+/*			2006 Benjamin Drieu (bdrieu@april.org)		      */
 /* 			http://www.grisbi.org				      */
 
 /*     This program is free software; you can redistribute it and/or modify */
@@ -1563,63 +1563,148 @@ classement_suivant:
 
 	case 1:
 
+	    /* aide mémoire...
+	     * principe de fonctionnement :
+	     * en haut les categs,
+	     * en dessous les sans categs,
+	     * en dessous les ventils
+	     * en dessous les virements
+	     *
+	     * pour chaque possibilité de l'opé 1, on va tester chaque possibilité de l'opé 2
+	     * cad on va tester l'opé 1 sur categ, pas de categ, ventil, virement
+	     * et pour chacun on teste l'opé 2 sur categ, pas de categ, ventil, virement
+	     * */
 	    if ( etat_courant -> utilise_categ )
 	    {
-		struct struct_categ * categ1, * categ2;
+		struct struct_categ * categ1 = NULL, * categ2 = NULL;
 		GSList * tmp;
 
 		/* Si les catégories sont nulles, on doit départager
 		 * entre virements, pas de categ ou opé ventilée on
 		 * met en 1er les opés sans categ, ensuite les
 		 * ventilations et enfin les virements */
-		if ( !operation_1 -> categorie )
+
+		if (operation_1 -> categorie)
 		{
-		    if ( operation_1 -> operation_ventilee )
+		    if (operation_2 -> categorie)
 		    {
-			if ( operation_2 -> relation_no_operation )
-			    return ( -1 );
-			else
-			    if ( !operation_2 -> operation_ventilee )
-				return ( 1 );
-		    }
-		    else
-		    {
-			if ( operation_1 -> relation_no_operation )
+			/* on a 2 categories, on retourne la strcmp entre les 2 */
+			gint retour;
+
+			if ( operation_1 -> categorie == operation_2 -> categorie )
 			{
-			    if ( !operation_2 -> relation_no_operation )
-				return ( 1 );
+			    /*       les catégories sont identiques, passe au classement suivant (ss categ) */
+			    pointeur = pointeur -> next;
+			    goto classement_suivant;
+			}
+
+			tmp = g_slist_find_custom ( liste_struct_categories,
+						    GINT_TO_POINTER ( operation_1 -> categorie ),
+						    ( GCompareFunc ) recherche_categorie_par_no );
+			if ( tmp )
+			    categ1 = tmp -> data;
+
+			tmp = g_slist_find_custom ( liste_struct_categories,
+						    GINT_TO_POINTER ( operation_2 -> categorie ),
+						    ( GCompareFunc ) recherche_categorie_par_no );
+			if ( tmp )
+			    categ2 = tmp -> data;
+
+			/* on vérifie quand même que les categs existent pour pas tout faire planter */
+			if (categ1)
+			{
+			    if (categ2)
+				retour = g_utf8_collate ( categ1 -> nom_categ, categ2 -> nom_categ );
+			    else
+				retour = -1;
 			}
 			else
-			    if ( operation_2 -> relation_no_operation
-				 ||
-				 operation_2 -> operation_ventilee )
-				return ( -1 );
+			{
+			    if (categ2)
+				retour = 1;
+			    else
+			    {
+				/* les 2 categs n'existent pas, on va donc passer les sous categs... et
+				 * aller au classement suivant */
+				pointeur = pointeur -> next;
+				retour = 0;
+			    }
+			}
+
+			if (retour)
+			    return retour;
+			else
+			{
+			    /*       les catégories sont identiques bien que de no différent,
+			     *       passe au classement suivant (ss categ) */
+			    pointeur = pointeur -> next;
+			    goto classement_suivant;
+			}
 		    }
+		    /* laissé comme ça pour se souvenir car compliqué, mais pourrait faire juste
+		     * un return -1 */
+		    if (operation_2 -> operation_ventilee)
+			return -1;
+		    if (operation_2 -> relation_no_operation)
+			return -1;
+		    return -1;
 		}
-		if ( ! operation_1 -> categorie || ! operation_2 -> categorie )
+		if (operation_1 -> operation_ventilee)
 		{
-		    return operation_1 -> categorie - operation_2 -> categorie;
+		    if (operation_2 -> categorie)
+			return 1;
+		    if (operation_2 -> relation_no_operation)
+			return -1;
+		    if (operation_2 -> operation_ventilee)
+		    {
+			/* on a 2 opérations ventilées, on ne peut départager ni au niveau catégorie,
+			 * ni au niveau sous categ, on passe donc le pointeur suivant pour aller à
+			 * celui d'encore après */
+			pointeur = pointeur -> next;
+			pointeur = pointeur -> next;
+			goto classement_suivant;
+		    }
+		    /* c'est une categ null, donc return 1 */
+		    return 1;
 		}
-
-		tmp = g_slist_find_custom ( liste_struct_categories,
-					    GINT_TO_POINTER ( operation_1 -> categorie ),
-					    ( GCompareFunc ) recherche_categorie_par_no );
-		if ( tmp )
-		    categ1 = tmp -> data;
-
-		tmp = g_slist_find_custom ( liste_struct_categories,
-					    GINT_TO_POINTER ( operation_2 -> categorie ),
-					    ( GCompareFunc ) recherche_categorie_par_no );
-		if ( tmp )
-		    categ2 = tmp -> data;
-
-		if ( operation_1 -> categorie != operation_2 -> categorie )
-		    return g_utf8_collate ( categ1 -> nom_categ, categ2 -> nom_categ );
-
+		if (operation_1 -> relation_no_operation)
+		{
+		    if (operation_2 -> categorie)
+			return 1;
+		    if (operation_2 -> operation_ventilee)
+			return 1;
+		    if (operation_2 -> relation_no_operation)
+		    {
+			/* les 2 opés sont des virements, on retourne un strcmp sur les comptes du virement
+			 * mais comme je suis très paresseux, je retourne juste la différence entre les nos
+			 * de comptes (FIXME...) */
+			if (operation_1 -> relation_no_compte == operation_2 -> relation_no_compte)
+			{
+			    /*       les virements sont identiques, passe au classement suivant après les ss categ) */
+			    pointeur = pointeur -> next;
+			    pointeur = pointeur -> next;
+			    goto classement_suivant;
+			}
+			return (operation_1 -> relation_no_compte == operation_2 -> relation_no_compte);
+		    }
+		    /* l'opé 2 n'a pas de categ */
+		    return 1;
+		}
+		/* à ce niveau, la categ de l'opé est nulle et ce n'est ni un virement ni une ventil,
+		 * on choise en fonction de l'opé 2 */
+		if (operation_2 -> categorie)
+		    return 1;
+		if (operation_2 -> operation_ventilee)
+		    return -1;
+		if (operation_2 -> relation_no_operation)
+		    return -1;
+		/* la categ de l'opé 2 est null aussi, on saute les ss categ pour aller voir la suite */
+		pointeur = pointeur -> next;
+		pointeur = pointeur -> next;
+		goto classement_suivant;
 	    }
-
-	    /*       les catégories sont identiques, passe au classement suivant */
-
+	    /* don't use category, go to the next sort */
+	    pointeur = pointeur -> next;
 	    pointeur = pointeur -> next;
 	    goto classement_suivant;
 
@@ -1633,8 +1718,8 @@ classement_suivant:
 		 &&
 		 etat_courant -> afficher_sous_categ )
 	    {
-		struct struct_sous_categ * scateg1, * scateg2;
-		struct struct_categ * categ1, * categ2;
+		struct struct_sous_categ * scateg1 = NULL, * scateg2 = NULL;
+		struct struct_categ * categ1 = NULL, * categ2 = NULL;
 		GSList * tmp;
 
 		if ( ! operation_1 -> categorie || ! operation_2 -> categorie )
@@ -1689,30 +1774,82 @@ classement_suivant:
 
 	    if ( etat_courant -> utilise_ib )
 	    {
-		struct struct_imputation * ib1, * ib2;
+		struct  struct_imputation *ib1 = NULL, * ib2 = NULL;
 		GSList * tmp;
 
-		if ( !operation_1 -> imputation || !operation_2 -> imputation )
-		    return ( operation_1 -> imputation - operation_2 -> imputation );
+		if (operation_1 -> imputation)
+		{
+		    if (operation_2 -> imputation)
+		    {
+			/* on a 2 ib, on retourne la strcmp entre les 2 */
+			gint retour;
 
-		tmp = g_slist_find_custom ( liste_struct_imputation,
-					    GINT_TO_POINTER ( operation_1 -> imputation ),
-					    ( GCompareFunc ) recherche_imputation_par_no );
-		if ( tmp )
-		    ib1 = tmp -> data;
+			if ( operation_1 -> imputation == operation_2 -> imputation )
+			{
+			    /*       les ib sont identiques, passe au classement suivant (ss ib) */
+			    pointeur = pointeur -> next;
+			    goto classement_suivant;
+			}
 
-		tmp = g_slist_find_custom ( liste_struct_imputation,
-					    GINT_TO_POINTER ( operation_2 -> imputation ),
-					    ( GCompareFunc ) recherche_imputation_par_no );
-		if ( tmp )
-		    ib2 = tmp -> data;
+			tmp = g_slist_find_custom ( liste_struct_imputation,
+						    GINT_TO_POINTER ( operation_1 -> imputation ),
+						    ( GCompareFunc ) recherche_imputation_par_no );
+			if ( tmp )
+			    ib1 = tmp -> data;
 
-		if ( ib1 && ib2 && ( ib1 != ib2 ) )
-		    return g_utf8_collate ( ib1 -> nom_imputation, ib2 -> nom_imputation );
+			tmp = g_slist_find_custom ( liste_struct_imputation,
+						    GINT_TO_POINTER ( operation_2 -> imputation ),
+						    ( GCompareFunc ) recherche_imputation_par_no );
+			if ( tmp )
+			    ib2 = tmp -> data;
+
+			/* on vérifie quand même que les ib existent pour pas tout faire planter */
+			if (ib1)
+			{
+			    if (ib2)
+				retour = g_utf8_collate ( ib1 -> nom_imputation, ib2 -> nom_imputation );
+			    else
+				retour = -1;
+			}
+			else
+			{
+			    if (ib2)
+				retour = 1;
+			    else
+			    {
+				/* les 2 ib n'existent pas, on va donc passer les sous ib... et
+				 * aller au classement suivant */
+				pointeur = pointeur -> next;
+				retour = 0;
+			    }
+			}
+
+			if (retour)
+			    return retour;
+			else
+			{
+			    /*       les ib sont identiques bien que de no différent,
+			     *       passe au classement suivant (ss ib) */
+			    pointeur = pointeur -> next;
+			    goto classement_suivant;
+			}
+		    }
+		    return -1;
+		}
+
+		/* à ce niveau, la ib de l'opé 1 est nulle
+		 * on choise en fonction de l'opé 2 */
+		if (operation_2 -> imputation)
+		    return 1;
+		/* la ib de l'opé 2 est null aussi, on saute les ss ib pour aller voir la suite */
+		pointeur = pointeur -> next;
+		pointeur = pointeur -> next;
+		goto classement_suivant;
 	    }
 
-	    /*       les ib sont identiques, passe au classement suivant */
+	    /* on n'utilise pas les ib, passe à la suite */
 
+	    pointeur = pointeur -> next;
 	    pointeur = pointeur -> next;
 	    goto classement_suivant;
 
@@ -1726,8 +1863,8 @@ classement_suivant:
 		 &&
 		 etat_courant -> afficher_sous_ib )
 	    {
-		struct struct_imputation * ib1, * ib2;
-		struct struct_sous_imputation * sib1, * sib2;
+		struct struct_imputation * ib1 = NULL, * ib2 = NULL;
+		struct struct_sous_imputation * sib1 = NULL, * sib2 = NULL;
 		GSList * tmp;
 
 		if ( !operation_1 -> imputation || !operation_2 -> imputation )
@@ -2600,6 +2737,14 @@ pas_decalage:
 				else
 				    montant = operation -> montant * operation -> taux_change - operation -> frais_change;
 			    }
+			    else if ( devise_operation -> no_devise_en_rapport ==
+				      devise_categ_etat -> no_devise )
+			    {
+				if ( devise_operation -> une_devise_1_egale_x_devise_2 )
+				    montant = operation -> montant * devise_operation -> change;
+				else
+				    montant = operation -> montant / devise_operation -> change;
+			    }
 			    else
 			    {
 				/* ne peut faire la conversion que s'il y a un rapport entre les 2 devises */
@@ -2654,17 +2799,25 @@ pas_decalage:
 				else
 				    montant = operation -> montant * operation -> taux_change - operation -> frais_change;
 			    }
+			    else if ( devise_operation -> no_devise_en_rapport ==
+				      devise_ib_etat -> no_devise )
+			    {
+				if ( devise_operation -> une_devise_1_egale_x_devise_2 )
+				    montant = operation -> montant * devise_operation -> change;
+				else
+				    montant = operation -> montant / devise_operation -> change;
+			    }
 			    else
 			    {
 				/* ne peut faire la conversion que s'il y a un rapport entre les 2 devises */
-				if ( devise_operation -> no_devise != devise_categ_etat -> no_devise_en_rapport )
+				if ( devise_operation -> no_devise != devise_ib_etat -> no_devise_en_rapport )
 				    montant = 0;
 				else
 				{
-				    if ( devise_categ_etat -> une_devise_1_egale_x_devise_2 )
-					montant = operation -> montant / devise_categ_etat -> change;
+				    if ( devise_ib_etat -> une_devise_1_egale_x_devise_2 )
+					montant = operation -> montant / devise_ib_etat -> change;
 				    else
-					montant = operation -> montant * devise_categ_etat -> change;
+					montant = operation -> montant * devise_ib_etat -> change;
 				}
 			    }
 			}
@@ -2707,17 +2860,25 @@ pas_decalage:
 				else
 				    montant = operation -> montant * operation -> taux_change - operation -> frais_change;
 			    }
+			    else if ( devise_operation -> no_devise_en_rapport ==
+				      devise_tiers_etat -> no_devise )
+			    {
+				if ( devise_operation -> une_devise_1_egale_x_devise_2 )
+				    montant = operation -> montant * devise_operation -> change;
+				else
+				    montant = operation -> montant / devise_operation -> change;
+			    }
 			    else
 			    {
 				/* ne peut faire la conversion que s'il y a un rapport entre les 2 devises */
-				if ( devise_operation -> no_devise != devise_categ_etat -> no_devise_en_rapport )
+				if ( devise_operation -> no_devise != devise_tiers_etat -> no_devise_en_rapport )
 				    montant = 0;
 				else
 				{
-				    if ( devise_categ_etat -> une_devise_1_egale_x_devise_2 )
-					montant = operation -> montant / devise_categ_etat -> change;
+				    if ( devise_tiers_etat -> une_devise_1_egale_x_devise_2 )
+					montant = operation -> montant / devise_tiers_etat -> change;
 				    else
-					montant = operation -> montant * devise_categ_etat -> change;
+					montant = operation -> montant * devise_tiers_etat -> change;
 				}
 			    }
 			}
@@ -2775,17 +2936,25 @@ pas_decalage:
 				else
 				    montant = operation -> montant * operation -> taux_change - operation -> frais_change;
 			    }
+			    else if ( devise_operation -> no_devise_en_rapport ==
+				      devise_compte_en_cours_etat -> no_devise )
+			    {
+				if ( devise_operation -> une_devise_1_egale_x_devise_2 )
+				    montant = operation -> montant * devise_operation -> change;
+				else
+				    montant = operation -> montant / devise_operation -> change;
+			    }
 			    else
 			    {
 				/* ne peut faire la conversion que s'il y a un rapport entre les 2 devises */
-				if ( devise_operation -> no_devise != devise_categ_etat -> no_devise_en_rapport )
+				if ( devise_operation -> no_devise != devise_compte_en_cours_etat -> no_devise_en_rapport )
 				    montant = 0;
 				else
 				{
-				    if ( devise_categ_etat -> une_devise_1_egale_x_devise_2 )
-					montant = operation -> montant / devise_categ_etat -> change;
+				    if ( devise_compte_en_cours_etat -> une_devise_1_egale_x_devise_2 )
+					montant = operation -> montant / devise_compte_en_cours_etat -> change;
 				    else
-					montant = operation -> montant * devise_categ_etat -> change;
+					montant = operation -> montant * devise_compte_en_cours_etat -> change;
 				}
 			    }
 			}
@@ -2825,6 +2994,14 @@ pas_decalage:
 				else
 				    montant = operation -> montant * operation -> taux_change - operation -> frais_change;
 			    }
+			    else if ( devise_operation -> no_devise_en_rapport ==
+				      devise_categ_etat -> no_devise )
+			    {
+				if ( devise_operation -> une_devise_1_egale_x_devise_2 )
+				    montant = operation -> montant * devise_operation -> change;
+				else
+				    montant = operation -> montant / devise_operation -> change;
+			    }
 			    else
 			    {
 				/* ne peut faire la conversion que s'il y a un rapport entre les 2 devises */
@@ -2877,6 +3054,14 @@ pas_decalage:
 				else
 				    montant = operation -> montant * operation -> taux_change - operation -> frais_change;
 			    }
+			    else if ( devise_operation -> no_devise_en_rapport ==
+				      devise_categ_etat -> no_devise )
+			    {
+				if ( devise_operation -> une_devise_1_egale_x_devise_2 )
+				    montant = operation -> montant * devise_operation -> change;
+				else
+				    montant = operation -> montant / devise_operation -> change;
+			    }
 			    else
 			    {
 				/* ne peut faire la conversion que s'il y a un rapport entre les 2 devises */
@@ -2920,7 +3105,7 @@ pas_decalage:
 			     !strcmp ( devise_categ_etat -> nom_devise, _("Euro") ))
 			    montant = operation -> montant / devise_operation -> change;
 			else
-				{
+			{
 			    /* s'il n'y a pas de taux de change, utilise le taux courant */
 			    if ( operation -> taux_change )
 			    {
@@ -2929,6 +3114,14 @@ pas_decalage:
 				else
 				    montant = operation -> montant * operation -> taux_change - operation -> frais_change;
 			    }
+			    else if ( devise_operation -> no_devise_en_rapport ==
+				      devise_categ_etat -> no_devise )
+			    {
+				if ( devise_operation -> une_devise_1_egale_x_devise_2 )
+				    montant = operation -> montant * devise_operation -> change;
+				else
+				    montant = operation -> montant / devise_operation -> change;
+			    }
 			    else
 			    {
 				/* ne peut faire la conversion que s'il y a un rapport entre les 2 devises */
@@ -3077,3 +3270,4 @@ void denote_struct_sous_jaccentes ( gint origine )
 }
 /*****************************************************************************************************/
 
+ 
