@@ -2,6 +2,7 @@
  *
  *     Copyright (C)	2001 Cédric Auger (cedric@grisbi.org) 
  *			2003 Benjamin Drieu (bdrieu@april.org) 
+ *			2005 Alain Portal (aportal@univ-montp2.fr) 
  * 			http://www.grisbi.org
  *
  * This library is free software; you can redistribute it and/or
@@ -469,53 +470,7 @@ GtkWidget *gtk_combofix_new_complex ( GSList *liste,
 static gint classe_alphabetique ( gchar *string_1,
 				  gchar *string_2 )
 {
-    /*   comme la fonction g_strcasecmp met les accents derrière, on magouille pour les prendre en compte */
-
-    string_1 = g_strdup ( string_1 );
-    string_1 = g_strdelimit ( string_1,
-			      "éÉèÈêÊ",
-			      'e' );
-    string_1 = g_strdelimit ( string_1,
-			      "çÇ",
-			      'c' );
-    string_1 = g_strdelimit ( string_1,
-			      "àÀ",
-			      'a' );
-    string_1 = g_strdelimit ( string_1,
-			      "ùûÙÛ",
-			      'u' );
-    string_1 = g_strdelimit ( string_1,
-			      "ôÔ",
-			      'o' );
-    string_1 = g_strdelimit ( string_1,
-			      "îÎ",
-			      'i' );
-
-    string_2 = g_strdup ( string_2 );
-    string_2 = g_strdelimit ( string_2,
-			      "éÉèÈêÊ",
-			      'e' );
-    string_2 = g_strdelimit ( string_2,
-			      "çÇ",
-			      'c' );
-    string_2 = g_strdelimit ( string_2,
-			      "àÀ",
-			      'a' );
-    string_2 = g_strdelimit ( string_2,
-			      "ùûÙÛ",
-			      'u' );
-    string_2 = g_strdelimit ( string_2,
-			      "ôÔ",
-			      'o' );
-    string_2 = g_strdelimit ( string_2,
-			      "îÎ",
-			      'i' );
-
-
-
-    return ( g_strcasecmp ( string_1,
-			    string_2 ));
-
+    return g_utf8_collate ( string_1, string_2 );
 }
 /* **************************************************************************************************** */
 
@@ -643,12 +598,16 @@ recherche_completion:
 	{
 	    if ( !case_sensitive )
 	    {
-		if ( !g_strncasecmp ( chaine, liste_tmp->data, strlen ( chaine ) ) )
+		if ( !g_utf8_collate ( g_utf8_casefold ( chaine, strlen ( chaine ) ),
+				       g_utf8_casefold ( liste_tmp->data, strlen ( chaine ) ) ))
 		    completion = liste_tmp -> data;
 	    }
 	    else
 	    {
-		if ( !strncmp ( chaine, liste_tmp->data, strlen ( chaine ) ) )
+		if ( !strcmp ( g_utf8_collate_key ( chaine, 
+						    strlen (chaine )),
+			       g_utf8_collate_key ( liste_tmp->data,
+						    strlen (chaine ))))
 		    completion = liste_tmp -> data;
 	    }
 
@@ -658,6 +617,7 @@ recherche_completion:
     else
 	completion = "";
 
+
     /* commence par vérifier l'entrée si force_text = 1 */
     /* si le mot n'existe pas dans la liste autorisée, efface ce qui a été ajouté */
 
@@ -709,8 +669,9 @@ recherche_completion:
 
 
     /* on commence à récupérer toutes les lignes qu'on va inclure dans la box */
-    /* si le nb de lignes est > à lignes_max, on n'affiche pas */
-
+    
+    /* si on a tapé du texte et que si le nb de lignes est > à lignes_max, on n'affiche pas */
+    /* si on a cliqué sur le bouton( dans ce cas, entree=-1), on affiche toutes les lignes */
 
     /* si on a clické sur l'arrow, on affiche toute la liste */
 
@@ -758,13 +719,11 @@ recherche_completion:
 		    string_tot = g_strconcat ( string,
 					       " : ",
 					       NULL );
-		    if ( !g_strncasecmp ( chaine,
-					  string_tot,
-					  strlen ( chaine )) 
+		    if ( !g_utf8_collate ( g_utf8_casefold ( chaine, strlen ( chaine ) ),
+					   g_utf8_casefold ( string_tot, strlen ( chaine )))
 			 ||
-			 !g_strncasecmp ( chaine,
-					  string_tot,
-					  strlen ( string_tot )))
+			 !g_utf8_collate ( g_utf8_casefold ( chaine, strlen ( chaine ) ),
+					   g_utf8_casefold ( string_tot, strlen ( string_tot ))))
 
 		    {
 			/* cette catégorie devra être affichée */
@@ -776,12 +735,8 @@ recherche_completion:
 		}
 		else
 		{
-		    if ( !g_strncasecmp ( chaine,
-					  g_strconcat ( categorie,
-							" : ",
-							string + 1,
-							NULL ),
-					  strlen ( chaine )))
+		    if ( !g_utf8_collate ( g_utf8_casefold ( chaine, strlen ( chaine ) ),
+					   g_utf8_casefold ( g_strconcat ( categorie, " : ", string + 1, NULL ), strlen ( chaine ))))
 		    {
 			/* cette sous-catég devra être affichée */
 
@@ -791,7 +746,9 @@ recherche_completion:
 		    }
 		}
 
-		if ( combofix -> lignes_max
+		if ( entree != GINT_TO_POINTER (-1)
+		     &&
+		     combofix -> lignes_max
 		     &&
 		     ligne_en_cours > combofix -> lignes_max )
 		{
@@ -840,13 +797,11 @@ recherche_completion:
 		string_tot = g_strconcat ( string,
 					   " : ",
 					   NULL );
-		if ( !g_strncasecmp ( chaine,
-				      string_tot,
-				      strlen ( chaine ) ) 
+		if ( !g_utf8_collate ( g_utf8_casefold ( chaine, strlen ( chaine ) ),
+				       g_utf8_casefold ( string_tot, strlen ( chaine )))
 		     ||
-		     !g_strncasecmp ( chaine,
-				      string_tot,
-				      strlen ( string_tot )))
+		     !g_utf8_collate ( g_utf8_casefold ( chaine, strlen ( chaine ) ),
+				       g_utf8_casefold ( string_tot, strlen ( string_tot ))))
 
 		{
 		    liste_affichee = g_slist_append ( liste_affichee,
@@ -856,12 +811,8 @@ recherche_completion:
 	    }
 	    else
 	    {
-		if ( !g_strncasecmp ( chaine,
-				      g_strconcat ( categorie,
-						    " : ",
-						    string + 1,
-						    NULL ),
-				      strlen ( chaine ) ) )
+		if ( !g_utf8_collate ( g_utf8_casefold ( chaine, strlen ( chaine ) ),
+				       g_utf8_casefold ( g_strconcat ( categorie, " : ", string + 1, NULL ), strlen ( chaine ))))
 		{
 		    liste_affichee = g_slist_append ( liste_affichee,
 						      string );
@@ -869,7 +820,9 @@ recherche_completion:
 		}
 	    }
 
-	    if ( combofix -> lignes_max
+	    if ( entree != GINT_TO_POINTER (-1)
+		 &&
+		 combofix -> lignes_max
 		 &&
 		 ligne_en_cours > combofix -> lignes_max )
 	    {
@@ -938,9 +891,6 @@ recherche_completion:
 
     style_label->bg[GTK_STATE_PRELIGHT] = couleur_bleue;
 
-
-
-
     liste_tmp = liste_affichee;
 
     menu_rempli = 0;
@@ -1188,8 +1138,6 @@ recherche_completion:
 	}
 
 
-
-
     if ( entree && completion )
     {
 	/* on affiche maintenant la complétion dans le combofix */
