@@ -66,7 +66,10 @@ int ofx_proc_statement_cb(struct OfxStatementData data, void * statement_data);
 gboolean recuperation_donnees_ofx ( gchar *nom_fichier )
 {
     gchar *argv[2];
-
+#ifdef _WIN32
+    gchar* current_working_directory = g_get_current_dir();
+#endif
+    
     liste_comptes_importes_ofx = NULL;
     compte_ofx_importation_en_cours = NULL;
     erreur_import_ofx = 0;
@@ -75,6 +78,29 @@ gboolean recuperation_donnees_ofx ( gchar *nom_fichier )
     /* 	la lib ofx ne tient pas compte du 1er argument */
     argv[1] = nom_fichier;
 
+#ifdef _WIN32
+    // There is some problem with not system global libofx installation:
+    // dtd file search is done with hardcoded pathes definition
+    // For windows version tihs path is set to "dtd;../dtd;." which work well when
+    // current directory is set to the grisbi.exe directory - startinig grisbi from app shortcut -
+    // but when user starts grisbi using file association feature by dbl-clicking on gsb file
+    // current directory is set to the gsb file location!
+    // => this fix is a "grosse bidouille" which set temporally the current directory to the
+    // grisbi app path!
+    win32_set_current_directory(win32_app_subdir_folder_path(""));
+
+    // Add some checks to have a more 'user friendly' error reporting
+    if (   (!LoadLibrary("libofx.dll")) 
+         ||(!LoadLibrary("osp151.dll"))
+         ||(!g_file_test("dtd/ofx160.dtd",G_FILE_TEST_EXISTS))
+        )
+    {
+        dialogue_error_hint(_("The OFX support can not be enabled!"), 
+                      g_strdup_printf (_("Cannot process OFX file '%s'"), nom_fichier));
+        return (FALSE);
+    }
+#endif
+
 #ifdef OFX_0_7
     ofx_context = libofx_get_new_context();
     ofx_set_status_cb ( ofx_context, ofx_proc_status_cb, NULL );
@@ -96,6 +122,11 @@ gboolean recuperation_donnees_ofx ( gchar *nom_fichier )
         return (FALSE);
     }
 
+#ifdef _WIN32
+    // Restore as soon as possible old current directory
+    win32_set_current_directory(current_working_directory);
+    utils_free(current_working_directory);
+#endif
     /*     le dernier compte n'a pas été ajouté à la liste */
 
     liste_comptes_importes_ofx = g_slist_append ( liste_comptes_importes_ofx,
@@ -262,8 +293,8 @@ int ofx_proc_account_cb(struct OfxAccountData data)
 
     if ( data.account_id_valid )
     {
-	compte_ofx_importation_en_cours -> id_compte = g_strdup ( data.account_id );
-	compte_ofx_importation_en_cours -> nom_de_compte = g_strdup ( data.account_name );
+	compte_ofx_importation_en_cours -> id_compte = latin2utf8 ( data.account_id );
+	compte_ofx_importation_en_cours -> nom_de_compte = latin2utf8 ( data.account_name );
     }
 
     compte_ofx_importation_en_cours -> origine = 1;
@@ -272,7 +303,7 @@ int ofx_proc_account_cb(struct OfxAccountData data)
 	compte_ofx_importation_en_cours -> type_de_compte = data.account_type;
 
     if ( data.currency_valid )
-	compte_ofx_importation_en_cours -> devise = g_strdup ( data.currency );
+	compte_ofx_importation_en_cours -> devise = latin2utf8 ( data.currency );
 
 
     return 0;
@@ -357,7 +388,7 @@ int ofx_proc_transaction_cb(struct OfxTransactionData data)
 			  sizeof ( struct struct_ope_importation ));
 
     if ( data.fi_id_valid )
-	ope_import -> id_operation = g_strdup ( data.fi_id );
+	ope_import -> id_operation = latin2utf8 ( data.fi_id );
 
     date = g_date_new ();
     if ( data.date_posted_valid )
@@ -383,10 +414,10 @@ int ofx_proc_transaction_cb(struct OfxTransactionData data)
 	ope_import -> date = ope_import -> date_de_valeur;
 
     if ( data.name_valid )
-	ope_import -> tiers = g_strdup ( data.name );
+	ope_import -> tiers = latin2utf8 ( data.name );
 
     if ( data.memo_valid )
-	ope_import -> notes = g_strdup ( data.memo );
+	ope_import -> notes = latin2utf8 ( data.memo );
 
     if ( data.check_number_valid )
 	ope_import -> cheque = my_atoi ( data.check_number );
