@@ -6,7 +6,7 @@
 /*                                                                            */
 /*     Copyright (C)	2000-2003 Cédric Auger (cedric@grisbi.org)	      */
 /*			2003-2004 Benjamin Drieu (bdrieu@april.org)	      */
-/*			2003-2004 Alain Portal (dionysos@grisbi.org)	      */
+/*			2003-2004 Alain Portal (aportal@univ-montp2.fr)       */
 /* 			http://www.grisbi.org				      */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
@@ -134,7 +134,7 @@ gint recherche_devise_par_nom ( struct struct_devise *devise,
 				gchar *nom )
 {
 
-    return ( g_strcasecmp ( g_strstrip ( devise_name(devise) ), nom ) );
+    return ( g_strcasecmp ( devise -> nom_devise, nom ) );
 
 }
 /* ************************************************************************************************************ */
