@@ -658,7 +658,7 @@ gchar * latin2utf8 (char * inchar)
     if ( g_utf8_validate ( inchar,
 			   -1,
 			   NULL ))
-	return inchar;
+	return g_strdup (inchar);
 			 
     inlen = strlen(inchar);
     outlen = 1024;
