@@ -1,3 +1,24 @@
+/* ************************************************************************** */
+/*  This program is free software; you can redistribute it and/or modify      */
+/*  it under the terms of the GNU General Public License as published by      */
+/*  the Free Software Foundation; either version 2 of the License, or         */
+/*  (at your option) any later version.                                       */
+/*                                                                            */
+/*  This program is distributed in the hope that it will be useful,           */
+/*  but WITHOUT ANY WARRANTY; without even the implied warranty of            */
+/*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             */
+/*  GNU General Public License for more details.                              */
+/*                                                                            */
+/*  You should have received a copy of the GNU General Public License         */
+/*  along with this program; if not, write to the Free Software               */
+/*  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+/*                                                                            */
+/* ************************************************************************** */
+#ifndef _UTILS_H_
+#define _UTILS_H_
+#include <glib.h>
+#include <gtk/gtk.h>
+
 gboolean met_en_prelight ( GtkWidget *event_box,
 		       GdkEventMotion *event,
 		       gpointer pointeur );
@@ -73,3 +94,7 @@ gint my_strncasecmp ( gchar *chaine_1,
 		     gint longueur );
 gchar *get_line_from_string ( gchar *string );
 
+
+#define utils_free(ptr) if(ptr) { g_free(ptr); ptr = NULL; }
+
+#endif
