@@ -32,6 +32,7 @@
 #include "utils_files.h"
 #include "print_config.h"
 #include "dialog.h"
+#include "utils.h"
 /*END_INCLUDE*/
 
 /*START_STATIC*/
@@ -49,7 +50,8 @@ extern GtkWidget *window;
  * Handler triggered by clicking on the button of a "print to file"
  * combo.  Pop ups a file selector.
  *
- * \param button GtkButton widget that triggered this handler.
+ * \param button GtkButton widget that triggered this handler.:625
+ *
  * \param data A pointer to a GtkEntry that will be filled with the
  *             result of the file selector.
  */
@@ -220,7 +222,9 @@ GtkWidget * my_file_chooser ()
 FILE* utf8_fopen(gchar* utf8filename,gchar* mode)
 {
     FILE*  pfd               = NULL;
-    gchar* syslocale_filename = g_filename_from_utf8(utf8filename,-1,NULL,NULL,NULL);
+    
+    gchar* syslocale_filename = g_locale_from_utf8(utf8filename,-1,NULL,NULL,NULL);
+
     if (syslocale_filename != NULL)
     {
         pfd = fopen(syslocale_filename,mode);
@@ -243,7 +247,7 @@ FILE* utf8_fopen(gchar* utf8filename,gchar* mode)
 gint utf8_open(gchar* utf8filename,gint mode)
 {
     gint fd                  = -1;
-    gchar* syslocale_filename = g_filename_from_utf8(utf8filename,-1,NULL,NULL,NULL);
+    gchar* syslocale_filename = g_locale_from_utf8(utf8filename,-1,NULL,NULL,NULL);
     if (syslocale_filename != NULL)
     {
         fd = open(syslocale_filename,mode);
@@ -266,7 +270,7 @@ gint utf8_open(gchar* utf8filename,gint mode)
 gint utf8_stat(gchar* utf8filename,struct stat* filestat)
 {
     gint status               = -1;
-    gchar* syslocale_filename = g_filename_from_utf8(utf8filename,-1,NULL,NULL,NULL);
+    gchar* syslocale_filename = g_locale_from_utf8(utf8filename,-1,NULL,NULL,NULL);
     if (syslocale_filename != NULL)
     {
         status = stat(syslocale_filename,filestat);
@@ -288,7 +292,7 @@ gint utf8_stat(gchar* utf8filename,struct stat* filestat)
 xmlDocPtr utf8_xmlParseFile(const gchar *utf8filename)
 { 
     xmlDocPtr ptr = NULL;
-    gchar* syslocale_filename = g_filename_from_utf8(utf8filename,-1,NULL,NULL,NULL);
+    gchar* syslocale_filename = g_locale_from_utf8(utf8filename,-1,NULL,NULL,NULL);
     if (syslocale_filename != NULL)
     {
         ptr = xmlParseFile(syslocale_filename);
@@ -311,7 +315,7 @@ xmlDocPtr utf8_xmlParseFile(const gchar *utf8filename)
 gint utf8_xmlSaveFormatFile(const gchar *utf8filename, xmlDocPtr cur, gint format)
 { 
     gint   status             = -1;
-    gchar* syslocale_filename = g_filename_from_utf8(utf8filename,-1,NULL,NULL,NULL);
+    gchar* syslocale_filename = g_locale_from_utf8(utf8filename,-1,NULL,NULL,NULL);
     if (syslocale_filename != NULL)
     {
         status = xmlSaveFormatFile(syslocale_filename,cur,format);
@@ -332,7 +336,7 @@ gint utf8_xmlSaveFormatFile(const gchar *utf8filename, xmlDocPtr cur, gint forma
 gint utf8_remove(const gchar* utf8filename)
 {
     gint   status             = -1;
-    gchar* syslocale_filename = g_filename_from_utf8(utf8filename,-1,NULL,NULL,NULL);
+    gchar* syslocale_filename = g_locale_from_utf8(utf8filename,-1,NULL,NULL,NULL);
     if (syslocale_filename != NULL)
     {
         status = remove(syslocale_filename);
@@ -346,11 +350,97 @@ gint utf8_remove(const gchar* utf8filename)
 /** 
  * Sanitize a safe filename.  All chars that are not normally allowed
  * are replaced by underscores.
- * Then the filename is converted to locale
  *
+ * \note: there is no convertion from utf8 to locale here. the result string is to
+ * be used by GTK dialog. Internal filename string should stay in utf8. only the utf8_xxx have
+ * to convert the filename to syslocale charset.
+ * 
  * \param filename Filename to sanitize.
  */
 gchar * safe_file_name ( gchar* filename )
 {
-    return g_filename_from_utf8(g_strdelimit( g_strdup(filename), "/\\:*?\"<>|", '_' ),-1,NULL,NULL,NULL);
+    return g_strdelimit( g_strdup(filename), "/\\:*?\"'<>|", '_' );
 }
+
+/**
+ * Compute the full (absolute and long version nuder Windows) of a path.
+ * 
+ * The function use utf8 charset for path as entry and output.
+ * A path can be a directory or a file name.
+ * 
+ * \caveats Under linux, be aware the function is using the current directory value to estimate the absolute path.
+ * If you call this function after having change the current directory, the result may be incosnsistent with the reality!
+ * example : you file is /home/foo/bar 
+ *  If the current directory is /home/foo  utf8_full_path(bar) will return "/home/foo/bar"
+ *  If you change directory  to /tmp utf8_full_path(bar) will return "/tmp/bar"
+ * 
+ * \param utf8_short_path path (file or directory) to expand
+ *
+ * \return In any case a new allocated buffer to free using g_free after use.
+ * At least the function return a copy of the path given as parameter.
+ *
+ * \note As I do not remember if there is any equivalent Windows _fullpath() function 
+ *  I have implemented a more than very light algorithm.
+ */
+gboolean utf8_path_is_ended_by_dir_separator(gchar* utf8_path)
+{
+    return ((g_strrstr_len(utf8_path,1,"/"))||(g_strrstr_len(utf8_path,1,"\\")));
+}
+gchar* utf8_full_path(gchar* utf8_short_path)
+{
+    gchar* utf8_full_path       = NULL;
+    gchar* syslocale_full_path  = NULL;
+    gchar* syslocale_short_path = g_locale_from_utf8(utf8_short_path,-1,NULL,NULL,NULL);
+    
+    if (syslocale_short_path)
+    {
+
+#ifdef _WIN32 
+        gchar* absolute_short_path  = NULL;
+
+        absolute_short_path = win32_full_path(syslocale_short_path);
+        syslocale_full_path = win32_long_name(absolute_short_path);
+
+        utils_free(absolute_short_path);
+#else 
+        // Note:When utf8_short_path is already an absolute one , we do nothing as utf8_short_path
+        // will be returned by default when syslocale_full_path is NULL
+        // 
+        if (!g_path_is_absolute(utf8_short_path))
+        {
+            gchar* current_dir = g_get_current_dir();
+	    gboolean is_directory = g_file_test ( utf8_short_path, G_FILE_TEST_IS_DIR );
+
+            syslocale_full_path = g_strconcat(current_dir,"/", utf8_short_path, (is_directory) ? "/" : NULL , NULL);
+            utils_free(current_dir);
+        }
+#endif
+
+        utils_free(syslocale_short_path);
+    }
+
+    if (syslocale_full_path)
+    {
+        utf8_full_path = g_locale_to_utf8(syslocale_full_path,-1,NULL,NULL,NULL);
+        utils_free(syslocale_full_path);
+    }
+    else
+    {
+        utf8_full_path = g_strdup(utf8_short_path);
+    }
+
+    // Be sure that the 'last' dir separator is still present when needed
+    if (utf8_path_is_ended_by_dir_separator(utf8_short_path)||g_file_test(utf8_short_path,G_FILE_TEST_IS_DIR))
+    {
+        if (!utf8_path_is_ended_by_dir_separator(utf8_full_path))
+        {
+            gchar* old_utf8_full_path = utf8_full_path;
+            utf8_full_path = g_strconcat(old_utf8_full_path,C_DIRECTORY_SEPARATOR,NULL);
+            utils_free(old_utf8_full_path);
+        }
+    }
+    
+    return utf8_full_path;
+}
+
+
